"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.invokeResource = void 0;
const execa = require("execa");
const path = require("path");
const constants_1 = require("./constants");
const pathManager_1 = require("./pathManager");
const invokeResource = (request, context) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    const [handlerClassName, handlerMethodName] = request.handler.split('::');
    let debug = '-agentlib:jdwp=transport=dt_socket,server=y,suspend=n,address=*:5005';
    if (request.debug) {
        debug = '-agentlib:jdwp=transport=dt_socket,server=y,suspend=y,address=*:5005';
    }
    const childProcess = execa('java', [
        '-jar',
        debug,
        path.join(pathManager_1.pathManager.getAmplifyPackageLibDirPath(constants_1.packageName), constants_1.relativeShimJarPath),
        path.join(request.srcRoot, request.package),
        handlerClassName,
        handlerMethodName,
    ], {
        input: request.event,
        env: Object.assign({ PATH: process.env.PATH }, request.envVars),
        extendEnv: false,
    });
    (_a = childProcess.stderr) === null || _a === void 0 ? void 0 : _a.pipe(process.stderr);
    (_b = childProcess.stdout) === null || _b === void 0 ? void 0 : _b.pipe(process.stdout);
    const { stdout, exitCode } = yield childProcess;
    if (exitCode !== 0) {
        throw new Error('LambdaFunctionInvokeError' + { message: `java failed, exit code was ${exitCode}` });
    }
    const lines = stdout.split('\n');
    const lastLine = lines[lines.length - 1];
    let result = lastLine;
    try {
        result = JSON.parse(lastLine);
    }
    catch (err) {
        context.print.warning('Could not parse function output as JSON. Using raw output.');
    }
    return result;
});
exports.invokeResource = invokeResource;
//# sourceMappingURL=invoke.js.map