import { AmplifyAppSyncSimulatorAuthenticationType, AppSyncSimulatorDataSourceBaseConfig, AppSyncSimulatorDataSourceConfig, AppSyncSimulatorDataSourceType, AppSyncSimulatorFunctionsConfig, AppSyncSimulatorMappingTemplate, AppSyncSimulatorSchemaConfig, AppSyncSimulatorTable, RESOLVER_KIND } from 'amplify-appsync-simulator/lib/type-definition';
declare type RequireAtLeastOne<T, Keys extends keyof T = keyof T> = Pick<T, Exclude<keyof T, Keys>> & {
    [K in Keys]-?: Required<Pick<T, K>> & Partial<Pick<T, Exclude<Keys, K>>>;
}[Keys];
export declare enum AppSyncSimulatorCustomDataSourceType {
    Http = "HTTP"
}
export declare type AppSyncSimulatorCustomFunctionsConfig = AppSyncSimulatorFunctionsConfig & {
    dataSource: string;
    type: string;
    field: string;
    substitutions: {};
    requestMappingTemplate: string;
    responseMappingTemplate: string;
};
export declare type AmplifyAppSyncSimulatorCustomConfig = {
    authenticationType: AmplifyAppSyncSimulatorAuthenticationType;
    mappingTemplatesLocation: string;
    functionConfigurationsLocation: string;
    defaultMappingTemplates: any;
    functionConfigurations: AppSyncSimulatorCustomFunctionsConfig[];
    substitutions: {};
    mappingTemplates: AmplifyAppSyncSimulatorCustomMappingTemplate[];
    dataSources?: AppSyncSimulatorDataSourceConfig[];
    schema: AppSyncSimulatorSchemaConfig;
    name: string;
    defaultAuthenticationType: AmplifyAppSyncSimulatorCustomConfig;
    authRoleName?: string;
    unAuthRoleName?: string;
    authAccessKeyId?: string;
    accountId?: string;
    apiKey?: string;
    additionalAuthenticationProviders: AmplifyAppSyncSimulatorCustomConfig[];
    tables?: AppSyncSimulatorTable[];
    userPoolConfig: {};
    openIDConnectConfig: {};
};
export declare type AmplifyAppSyncSimulatorCustomMappingTemplate = AppSyncSimulatorMappingTemplate & {
    kind: RESOLVER_KIND;
    field: string;
    type: string;
    dataSource: string;
    functions: string[];
    substitutions: {};
    name: string;
};
export interface AppSyncSimulatorOpenSearchConfig extends AppSyncSimulatorDataSourceBaseConfig {
    type: AppSyncSimulatorDataSourceType.OpenSearch | `${AppSyncSimulatorDataSourceType.OpenSearch}`;
    endpoint: string;
}
export interface AppSyncSimulatorHttpConfig extends AppSyncSimulatorDataSourceBaseConfig {
    name: string;
    type: AppSyncSimulatorCustomDataSourceType.Http | `${AppSyncSimulatorCustomDataSourceType.Http}`;
    config: {
        endpoint: string;
    };
}
export declare type AppSyncSimulatorDataSourceCustomConfig = AppSyncSimulatorDataSourceConfig | AppSyncSimulatorOpenSearchConfig | AppSyncSimulatorHttpConfig;
export declare type Maybe<T> = null | undefined | T;
export declare type Event = Record<string, any>;
export declare type Callback = (event: any, context: ContextObject, done: ContextObject['cb']) => void;
export declare type ContextObject = {
    name: string;
    attempt: number;
    cb: (err: Maybe<Error>, result?: Event) => void | Callback | Promise<void | Callback>;
    done: ContextObject['cb'];
    succeed: (result: Event) => void;
    fail: (err: Error) => void;
};
export declare type Options = {
    location?: Maybe<string>;
    stateMachine?: Maybe<string>;
    lambdaEndpoint?: Maybe<string>;
    dynamoDb?: {};
    detailedLog?: boolean;
    l?: boolean;
    [key: string]: any;
    stage?: string;
    region?: string;
} & RequireAtLeastOne<{
    eventFile?: Maybe<string>;
    event?: Maybe<string>;
    e?: Options['event'];
    ef?: Options['eventFile'];
}, 'event' | 'e'>;
declare const DEFAULT_MAPPING_TEMPLATE_LOCATION = "mapping-templates";
declare const DEFAULT_ENCODING = "utf8";
declare const DEFAULT_SCHEMA_FILE = "schema.graphql";
declare const DEFAULT_HTTP_METHOD = "POST";
declare const DEFAULT_RESOLVER_TYPE = "UNIT";
declare const MappingTemplateType: {
    MAPPING_TEMPLATE: string;
    FUNCTION_CONFIGURATION: string;
};
export { DEFAULT_MAPPING_TEMPLATE_LOCATION, DEFAULT_ENCODING, DEFAULT_SCHEMA_FILE, DEFAULT_HTTP_METHOD, DEFAULT_RESOLVER_TYPE, MappingTemplateType, };
